@@ -331,7 +331,7 @@ class pi3dObj:
       for line in f:
         if not re.match('^'+self.entry+':?', line):
           continue
-        self.log.debug("getPositionFromFile - reading properties for entry {}".format(self.entry))
+        self.log.pos_debug("getPositionFromFile - reading properties for entry {}".format(self.entry))
         val_change  = 0
         entry_found = True
         expr_x = "undef"; expr_y = "undef"; expr_fs = "undef"; expr_ml = "undef"; expr_ps = "undef"; expr_spng = "undef"; expr_sp = "undef"; expr_col = "undef"; expr_jus = "undef";
